<?php

/**
 * @package         Google Structured Data
 * @version         5.0.2 Free
 * 
 * @author          Tassos Marinos <info@tassos.gr>
 * @link            http://www.tassos.gr
 * @copyright       Copyright © 2021 Tassos Marinos All Rights Reserved
 * @license         GNU GPLv3 <http://www.gnu.org/licenses/gpl.html> or later
*/

defined('_JEXEC') or die('Restricted access');

extract($displayData);

use Joomla\CMS\Language\Text;
use Joomla\CMS\Router\Route;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Component\ComponentHelper;

if (!$disabled)
{
	JHtml::script('https://cdn.jsdelivr.net/npm/sortablejs@latest/Sortable.min.js');

	// Required in the front-end for the media manager to work
	if (!defined('nrJ4'))
	{
		JHtml::_('behavior.modal');
		// Front-end editing: The below script is required for front-end media library selection to work as its missing from parent window when called
		if (JFactory::getApplication()->isClient('site'))
		{
			?>
			<script>
			function jInsertFieldValue(value, id) {
				var old_id = document.id(id).value;
				if (old_id != id) {
					var elem = document.id(id)
					elem.value = value;
					elem.fireEvent("change");
				}
			}
			</script>
			<?php
		}
	}
	else
	{
		HTMLHelper::_('bootstrap.dropdown', '.dropdown-toggle');
		
		$doc = JFactory::getApplication()->getDocument();
		$doc->addScriptOptions('media-picker', [
			'images' => array_map(
				'trim',
				explode(
					',',
					ComponentHelper::getParams('com_media')->get(
						'image_extensions',
						'bmp,gif,jpg,jpeg,png'
					)
				)
			)
		]);

		$wam = $doc->getWebAssetManager();
		$wam->useScript('webcomponent.media-select');
		
		Text::script('JFIELD_MEDIA_LAZY_LABEL');
		Text::script('JFIELD_MEDIA_ALT_LABEL');
		Text::script('JFIELD_MEDIA_ALT_CHECK_LABEL');
		Text::script('JFIELD_MEDIA_ALT_CHECK_DESC_LABEL');
		Text::script('JFIELD_MEDIA_CLASS_LABEL');
		Text::script('JFIELD_MEDIA_FIGURE_CLASS_LABEL');
		Text::script('JFIELD_MEDIA_FIGURE_CAPTION_LABEL');
		Text::script('JFIELD_MEDIA_LAZY_LABEL');
		Text::script('JFIELD_MEDIA_SUMMARY_LABEL');
	}
}

// Javascript files should always load as they are used to populate the Gallery Manager via Dropzone
JHtml::script('plg_system_nrframework/dropzone.min.js', ['relative' => true, 'version' => 'auto']);
JHtml::script('plg_system_nrframework/widgets/gallery/manager_init.js', ['relative' => true, 'version' => 'auto']);
JHtml::script('plg_system_nrframework/widgets/gallery/manager.js', ['relative' => true, 'version' => 'auto']);

if ($load_stylesheet)
{
	JHtml::stylesheet('plg_system_nrframework/widgets/gallerymanager.css', ['relative' => true, 'version' => 'auto']);
}
?>
<!-- Gallery Manager -->
<div class="nrf-widget nrf-gallery-manager<?php echo $css_class; ?>" data-widget-settings="<?php echo htmlspecialchars(json_encode($widget_settings)); ?>">
	<!-- Make Joomla client-side form validator happy by adding a fake hidden input field when the Gallery is required. -->
	<?php if ($required) { ?>
		<input type="hidden" required class="required" id="<?php echo $id; ?>"/>
	<?php } ?>

	<!-- Actions -->
	<div class="nrf-gallery-actions">
		<button class="button-item nrf-gallery-select-unselect-button select<?php echo (!count($gallery_items)) ? ' is-disabled' : ''; ?>" title="<?php echo Text::_('NR_GALLERY_MANAGER_SELECT_UNSELECT_IMAGES'); ?>"><span class="icon icon-checkbox-unchecked"></span><span class="text" data-select-text="<?php echo Text::_('NR_GALLERY_MANAGER_SELECT_ALL_ITEMS'); ?>" data-unselect-text="<?php echo Text::_('NR_GALLERY_MANAGER_UNSELECT_ALL_ITEMS'); ?>"><?php echo Text::_('NR_GALLERY_MANAGER_SELECT_ALL_ITEMS'); ?></span></button>
		<div class="main-buttons">
			<div class="btn-group add-button<?php echo !defined('nrJ4') ? ' dropdown' : ''; ?> ">
				<button class="button-item add nrf-gallery-add-item-button" onclick="return false;" title="<?php echo Text::_('NR_GALLERY_MANAGER_ADD_IMAGES'); ?>"><span class="icon-pictures"></span><?php echo Text::_('NR_GALLERY_MANAGER_ADD_IMAGES'); ?></button>
				<button class="button-item add dropdown-toggle dropdown-toggle-split" data-<?php echo defined('nrJ4') ? 'bs-' : ''; ?>toggle="dropdown" title="<?php echo Text::_('NR_GALLERY_MANAGER_ADD_DROPDOWN'); ?>">
					<span class="caret"></span>
				</button>
				<ul class="dropdown-menu">
					<li>
						<a <?php echo !defined('nrJ4') ? 'rel="{handler: \'iframe\', size: {x: 640, y: 640}}" href="' . JURI::root() . 'administrator/?option=com_media&view=images&tmpl=component&fieldid=' . $id . '_uploaded_file"' : 'href="#" data-bs-toggle="modal" data-bs-target="#nrf-GalleryMediaManager"'; ?> class="dropdown-item nrf-gallery-browse-item-button<?php echo !defined('nrJ4') ? ' modal' : ''; ?> popup" title="<?php echo Text::_('NR_GALLERY_MANAGER_BROWSE_MEDIA_LIBRARY'); ?>"><span class="icon-folder-open"></span><?php echo Text::_('NR_GALLERY_MANAGER_BROWSE_MEDIA_LIBRARY'); ?></a>
					</li>
				</ul>
			</div>
		</div>
		<a href="#" class="button-item delete-dark nrf-gallery-remove-selected-items-button<?php echo (!count($gallery_items)) ? ' is-disabled' : ''; ?>" title="<?php echo Text::_('NR_GALLERY_MANAGER_REMOVE_SELECTED_IMAGES'); ?>">
			<span class="icon-delete"></span><?php echo Text::_('NR_GALLERY_MANAGER_REMOVE_SELECTED_IMAGES'); ?><span class="total-items">0</span>
		</a>
		<a href="#" class="button-item delete nrf-gallery-remove-all-items-button<?php echo (!count($gallery_items)) ? ' is-disabled' : ''; ?>" title="<?php echo Text::_('NR_GALLERY_MANAGER_REMOVE_IMAGES'); ?>">
			<span class="icon-delete"></span><?php echo Text::_('NR_GALLERY_MANAGER_REMOVE_IMAGES'); ?>
		</a>
		<input type="hidden" class="media_uploader_file" id="<?php echo $id; ?>_uploaded_file" />
	</div>
	<!-- /Actions -->

	<!-- Dropzone -->
	<div
		data-inputname="<?php echo $name; ?>"
		data-maxfilesize="<?php echo $max_file_size; ?>"
		data-maxfiles="<?php echo $limit_files; ?>"
		data-acceptedfiles="<?php echo $allowed_file_types; ?>"
		data-value='<?php echo ($gallery_items) ? json_encode($gallery_items) : ''; ?>'
		data-baseurl='<?php echo JURI::base(); ?>'
		class="nrf-gallery-dz">
		<!-- DZ Message Wrapper -->
		<div class="dz-message">
			<!-- Message -->
			<div class="dz-message-center">
				<span class="text"><?php echo Text::_('NR_GALLERY_MANAGER_DRAG_AND_DROP_TEXT'); ?></span>
				<span class="browse"><?php echo Text::_('NR_GALLERY_MANAGER_BROWSE'); ?></span>
			</div>
			<!-- /Message -->
		</div>
		<!-- /DZ Message Wrapper -->
	</div>
	<!-- /Dropzone -->

	<!-- Dropzone Preview Template -->
	<div class="nrf-gallery-dz-preview">
		<div class="nrf-gallery-preview-item template" draggable="true" data-item-id="">
			<div class="delete-item-checkbox" title="<?php echo Text::_('NR_GALLERY_MANAGER_CHECK_TO_DELETE_ITEMS'); ?>">
				<input type="checkbox" class="nrf-gallery-to-be-deleted" />
				<div></div>
			</div>
			<div class="dz-status"></div>
			<div class="dz-actions">
				<a href="#" class="nrf-gallery-preview-remove-item" title="<?php echo Text::_('NR_GALLERY_MANAGER_CLICK_TO_DELETE_ITEM'); ?>" data-dz-remove>×</a>
			</div>
			<div class="dz-thumb">
				<div class="dz-progress"><span class="text"><?php echo Text::_('NR_GALLERY_MANAGER_UPLOADING'); ?></span><span class="dz-upload" data-dz-uploadprogress></span></div>
				<div class="nrf-gallery-preview-in-queue"><?php echo Text::_('NR_GALLERY_MANAGER_IN_QUEUE'); ?></div>
				<img data-dz-thumbnail />
			</div>
			<div class="dz-details">
				<div class="detail">
					<input name="<?php echo $name; ?>[title]" class="item-title" type="text" value="" placeholder="<?php echo Text::_('NR_GALLERY_MANAGER_TITLE_HINT'); ?>" title="<?php echo Text::_('NR_GALLERY_MANAGER_TITLE_HINT'); ?>" />
				</div>
				<div class="detail">
					<textarea name="<?php echo $name; ?>[description]" class="item-description" placeholder="<?php echo Text::_('NR_GALLERY_MANAGER_CAPTION_DESCRIPTION_HINT'); ?>" title="<?php echo Text::_('NR_GALLERY_MANAGER_CAPTION_DESCRIPTION_HINT'); ?>" rows="2"></textarea>
				</div>
			</div>
			<div class="dz-progress">
				<div class="nrf-gallery-preview-progress"><span class="dz-upload" data-dz-uploadprogress></span></div>
			</div>
			<div class="nrf-gallery-preview-error"><div data-dz-errormessage></div></div>
			<input type="hidden" value="" class="item-thumbnail" name="<?php echo $name; ?>[thumbnail]" />
			<input type="hidden" value="" class="item-media-upload-source" name="<?php echo $name; ?>[media_upload_source]" />
			<input type="hidden" value="" class="item-copied-from-media-uploader" name="<?php echo $name; ?>[copied_from_media_uploader]" />
		</div>
	</div>
	<!-- /Dropzone Preview Template -->

	<?php
	// Print Joomla 4 Media Manager modal only if Gallery is not disabled
	if (defined('nrJ4') && !$disabled)
	{
		echo JHtml::_('bootstrap.renderModal', 'nrf-GalleryMediaManager', [
			'title'       => Text::_('NR_GALLERY_MANAGER_SELECT_ITEM'),
			'url' 		  => Route::_(JURI::root() . 'administrator?option=com_media&view=media&tmpl=component'),
			'height'      => '400px',
			'width'       => '800px',
			'bodyHeight'  => 80,
			'modalWidth'  => 80,
			'backdrop' 	  => 'static',
			'footer'      => '<button type="button" class="btn btn-secondary nrf-gallery-button-save-selected button-save-selected" data-bs-dismiss="modal">' . Text::_('JSELECT') . '</button>' . '<button type="button" class="btn btn-secondary" data-bs-dismiss="modal">' . Text::_('JCANCEL') . '</button>',
		]);
	}
	?>
</div>
<!-- /Gallery Manager -->